@@ -452,7 +452,7 @@ function xreorder( counter ) {
 }
 
 function update_header( counter, key, uri ) {
-  if( uri==":PRE:" ) {
+  if( uri==":PRE:" || uri==":LOOKUPFILE:" ) {
     Element.update( 'header'+counter, key.escapeHTML() );
   } else {
     Element.update( 'header'+counter,
@@ -770,7 +770,7 @@ function xnewkey( o, uri ) {
 	'				<input type="text" name="newkey" id="key'+next_counter+'" value="'+key.escapeHTML()+'">'+
 	'			</td>'+
 	'		</tr>'+
-	(uri==":PRE:"
+	(uri==":PRE:" || uri==":LOOKUPFILE:"
 	 ? ('		<input type="hidden" name="newuri" id="uri'+next_counter+'" value="'+uri.escapeHTML()+'">')
 	 : ('		<tr>'+
 	    '			<td class="tdcol1">New Uri:</td>'+
